==> eam-wshub-proxyclient-11.4-4-sources.jar: net/datastream/schemas/mp_fields/CLASSLINEARREFERENCECLASSID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour CLASSLINEARREFERENCECLASSID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="CLASSLINEARREFERENCECLASSID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CLASSID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LINEARREFERENCECLASSID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CLASSLINEARREFERENCECLASSID_Type", propOrder = {
    "classid",
    "linearreferenceclassid"
})
public class CLASSLINEARREFERENCECLASSID_Type {

    @XmlElement(name = "CLASSID", required = true)
    protected CLASSID_Type classid;
    @XmlElement(name = "LINEARREFERENCECLASSID", required = true)
    protected CLASSID_Type linearreferenceclassid;

    /**
     * Obtient la valeur de la propriété classid.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getCLASSID() {
        return classid;
    }

    /**
     * Définit la valeur de la propriété classid.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setCLASSID(CLASSID_Type value) {
        this.classid = value;
    }

    /**
     * Obtient la valeur de la propriété linearreferenceclassid.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getLINEARREFERENCECLASSID() {
        return linearreferenceclassid;
    }

    /**
     * Définit la valeur de la propriété linearreferenceclassid.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setLINEARREFERENCECLASSID(CLASSID_Type value) {
        this.linearreferenceclassid = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/CLASSLINEARREFERENCECLASSID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CLASSLINEARREFERENCECLASSID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CLASSLINEARREFERENCECLASSID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CLASSID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LINEARREFERENCECLASSID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CLASSLINEARREFERENCECLASSID_Type", propOrder = {
    "classid",
    "linearreferenceclassid"
})
public class CLASSLINEARREFERENCECLASSID_Type {

    @XmlElement(name = "CLASSID", required = true)
    protected CLASSID_Type classid;
    @XmlElement(name = "LINEARREFERENCECLASSID", required = true)
    protected CLASSID_Type linearreferenceclassid;

    /**
     * Gets the value of the classid property.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getCLASSID() {
        return classid;
    }

    /**
     * Sets the value of the classid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setCLASSID(CLASSID_Type value) {
        this.classid = value;
    }

    /**
     * Gets the value of the linearreferenceclassid property.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getLINEARREFERENCECLASSID() {
        return linearreferenceclassid;
    }

    /**
     * Sets the value of the linearreferenceclassid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setLINEARREFERENCECLASSID(CLASSID_Type value) {
        this.linearreferenceclassid = value;
    }

}
